==> contentsquare-3.8.0.tar.gz: ios/Classes/Infrastructure/Core/MethodCallExecutor/Agents/WebViewDisposeAgent.swift <==
/// `MethodCallAgent` used to handle WebView dispose event
class WebViewDisposeAgent: MethodCallAgent {

    internal init(handler: OnWebViewDisposeHandler) {
        self._handler = handler
    }

    /// Message to use in case of error during native call.
    static let exceptionMessage = "Error while handling the WebView dispose event."

    /// Message in case of "user_script" parameter missing
    static let missingUserScriptParameter =  "Missing user_script parameter."

    /// Message in case of "channel_name" parameter missing
    static let missingChannelNameParameter =  "Missing channel_name parameter."

    private let _handler: OnWebViewDisposeHandler

    var nativeExceptionMessage: String? {
        return WebViewDisposeAgent.exceptionMessage
    }

    func execute(data: ExecutionData) throws -> ExecutionResponse {
        let arguments: [String : Any] = data.call.arguments as? [String : Any] ?? [:]

        guard let userScript = arguments["user_script"] as? String else {
            throw FailedExecutionError(
                reason: FailedExecutionResponseReason.missingArgument,
                message: WebViewDisposeAgent.missingUserScriptParameter,
                cause: nil
            )
        }

        guard let channelName = arguments["channel_name"] as? String else {
            throw FailedExecutionError(
                reason: FailedExecutionResponseReason.missingArgument,
                message: WebViewDisposeAgent.missingChannelNameParameter,
                cause: nil
            )
        }

        self._handler.onWebViewDispose(userScript: userScript, channelName: channelName)

        return ExecutionResponse.succeed(result: nil)
    }

}

/// The class that will handle the event of WebView dispose.
protocol OnWebViewDisposeHandler: AnyObject {

    /// Inform of the WebView dispose event
    ///
    /// - Parameter userScript: The [WKUserScript] source that is injected in the WebView
    /// - Parameter channelName: The name of channel injected in the WebView as user script
    func onWebViewDispose(userScript: String, channelName: String)
}

==> contentsquare-3.9.0.tar.gz: ios/Classes/Infrastructure/Core/MethodCallExecutor/Agents/WebViewDisposeAgent.swift <==
/// `MethodCallAgent` used to handle WebView dispose event
class WebViewDisposeAgent: MethodCallAgent {

    internal init(handler: OnWebViewDisposeHandler?) {
        self._handler = handler
    }

    /// Message to use in case of error during native call.
    static let exceptionMessage = "Error while handling the WebView dispose event."

    /// Message in case of "user_script" parameter missing
    static let missingUserScriptParameter =  "Missing user_script parameter."

    /// Message in case of "channel_name" parameter missing
    static let missingChannelNameParameter =  "Missing channel_name parameter."

    private let _handler: OnWebViewDisposeHandler?

    var nativeExceptionMessage: String? {
        return WebViewDisposeAgent.exceptionMessage
    }

    func execute(data: ExecutionData) throws -> ExecutionResponse {
        let arguments: [String : Any] = data.call.arguments as? [String : Any] ?? [:]

        guard let userScript = arguments["user_script"] as? String else {
            throw FailedExecutionError(
                reason: FailedExecutionResponseReason.missingArgument,
                message: WebViewDisposeAgent.missingUserScriptParameter,
                cause: nil
            )
        }

        guard let channelName = arguments["channel_name"] as? String else {
            throw FailedExecutionError(
                reason: FailedExecutionResponseReason.missingArgument,
                message: WebViewDisposeAgent.missingChannelNameParameter,
                cause: nil
            )
        }

        self._handler?.onWebViewDispose(userScript: userScript, channelName: channelName)

        return ExecutionResponse.succeed(result: nil)
    }

}

/// The class that will handle the event of WebView dispose.
protocol OnWebViewDisposeHandler: AnyObject {

    /// Inform of the WebView dispose event
    ///
    /// - Parameter userScript: The [WKUserScript] source that is injected in the WebView
    /// - Parameter channelName: The name of channel injected in the WebView as user script
    func onWebViewDispose(userScript: String, channelName: String)
}
